@@ -21,6 +21,7 @@
 
 #include "qgis_core.h"
 #include "qgis_sip.h"
+#include "qgis.h"
 
 class QgsLayerTreeGroup;
 class QgsLayerTreeNode;
@@ -39,7 +40,6 @@ class QgsProject;
  * If a layer is completely removed from the layer tree, it will be also removed
  * from the map layer registry.
  *
- * \since QGIS 2.4
  */
 class CORE_EXPORT QgsLayerTreeRegistryBridge : public QObject
 {
@@ -73,7 +73,7 @@ class CORE_EXPORT QgsLayerTreeRegistryBridge : public QObject
     /**
      * Set where the new layers should be inserted - can be used to follow current selection.
      * By default it is root group with zero index.
-     * \deprecated since QGIS 3.10 use setLayerInsertionPoint( const InsertionPoint &insertionPoint ) instead
+     * \deprecated QGIS 3.10. Use setLayerInsertionPoint( const InsertionPoint &insertionPoint ) instead.
      */
     Q_DECL_DEPRECATED void setLayerInsertionPoint( QgsLayerTreeGroup *parentGroup, int index ) SIP_DEPRECATED;
 
@@ -84,11 +84,22 @@ class CORE_EXPORT QgsLayerTreeRegistryBridge : public QObject
      */
     void setLayerInsertionPoint( const InsertionPoint &insertionPoint );
 
+    /**
+     * Sets the insertion \a method used to add layers to the tree
+     * \since QGIS 3.30
+     */
+    void setLayerInsertionMethod( Qgis::LayerTreeInsertionMethod method ) { mInsertionMethod = method; }
+
+    /**
+     * Returns the insertion method used to add layers to the tree
+     * \since QGIS 3.30
+     */
+    Qgis::LayerTreeInsertionMethod layerInsertionMethod() const { return mInsertionMethod; }
+
   signals:
 
     /**
      * Tell others we have just added layers to the tree (used in QGIS to auto-select first newly added layer)
-     * \since QGIS 2.6
      */
     void addedLayersToLayerTree( const QList<QgsMapLayer *> &layers );
 
@@ -110,6 +121,7 @@ class CORE_EXPORT QgsLayerTreeRegistryBridge : public QObject
     bool mNewLayersVisible;
 
     InsertionPoint mInsertionPoint;
+    Qgis::LayerTreeInsertionMethod mInsertionMethod = Qgis::LayerTreeInsertionMethod::AboveInsertionPoint;
 };
 
 #endif // QGSLAYERTREEREGISTRYBRIDGE_H
